package game;

import game.DeadGame.Difficulty;
import main.Art;
import main.Art.Bitmap;
import main.GameComponent;
import main.InputHandler;

public class MainMenu {
	private InputHandler inputHandler;
	private DeadGame game;
	private boolean optionsFlag; //If player wants to change settings, sets to true.
	
	public enum MenuOption {
		START(Art.start, 10, 70),
		OPTIONS(Art.options, 10, 80),
		
		//Options
		DIFFICULTY(Art.difficulty_option, 10, 10),
		BACK(Art.back_option, 10, 80),
		
		//Retry
		YES(Art.yes_option, 35, 70),
		NO(Art.no_option, 100, 70);

		public Bitmap bitmap;
		public int xOffset, yOffset;
		
		private MenuOption(Bitmap bitmap, int x, int y) {
			this.bitmap = bitmap;
			this.xOffset = x;
			this.yOffset = y;
		}
	}
	
	public MainMenu(DeadGame g) {
		inputHandler = g.inputHandler;
		game = g;
		
		optionsFlag = false;
	}

	public void tick() {
		if (!game.hasGameStarted()) {
			if (game.isAskingForRetry()) {
				menuOptionTick(MenuOption.YES);
				menuOptionTick(MenuOption.NO);
			}
			else {
				if (!optionsFlag) {
					menuOptionTick(MenuOption.START);
					menuOptionTick(MenuOption.OPTIONS);
				}
				else if (optionsFlag) {
					menuOptionTick(MenuOption.DIFFICULTY);
					menuOptionTick(MenuOption.BACK);
				}
			}
		}
	}
	
	private void menuOptionTick(MenuOption menu) {
		int x0 = menu.xOffset * GameComponent.SCALE;
		int x1 = (menu.xOffset + menu.bitmap.width) * GameComponent.SCALE;
		int y0 = menu.yOffset * GameComponent.SCALE;
		int y1 = (menu.yOffset + menu.bitmap.height) * GameComponent.SCALE;
		
		if (inputHandler.mouseX > x0 && inputHandler.mouseX < x1 && inputHandler.mouseY > y0 && inputHandler.mouseY < y1) {
			if (inputHandler.mouseClicked) {
				inputHandler.mouseClicked = false;
				//Do Action
				switch (menu) {
					case START:
						if (!optionsFlag)
							game.setGameMenuFlag(MenuOption.START);
						break;
					case OPTIONS:
						if (!optionsFlag)
							optionsFlag = true;
						break;
					case DIFFICULTY:
						//Hacky attempt
						if (game.getComputerDifficulty() == Difficulty.AI_EASY)
							game.setComputerDifficulty(Difficulty.AI_NORMAL);
						else if (game.getComputerDifficulty() == Difficulty.AI_NORMAL)
							game.setComputerDifficulty(Difficulty.AI_HARD);
						else if (game.getComputerDifficulty() == Difficulty.AI_HARD)
							game.setComputerDifficulty(Difficulty.AI_HARDER);
						else if (game.getComputerDifficulty() == Difficulty.AI_HARDER)
							game.setComputerDifficulty(Difficulty.AI_EASY);
						break;
					case BACK:
						if (optionsFlag)
							optionsFlag = false;
						break;
					case YES:
						game.confirmRetry();
						break;
					case NO:
						game.cancelRetry();
						break;
				}
			}
		}
	}

	public void render() {
		if (!game.hasGameStarted()) {
			if (game.isAskingForRetry()) {
				draw(Art.retry_option, 55, 40);
				draw(Art.yes_option, 35, 70);
				draw(Art.no_option, 100, 70);
			}
			else {
				if (!optionsFlag) {
					draw(Art.logo, 0, 0);
					draw(Art.start, 10, 70);
					draw(Art.options, 10, 80);
				}
				else if (optionsFlag) {
					draw(Art.difficulty_option, 10, 10);
					draw(game.getComputerDifficulty().bitmap, 20 + Art.difficulty_option.width, 10);
					draw(Art.back_option, 10, 80);
				}
			}
		}

	}
	
	private void draw(Bitmap bitmap, int xOffset, int yOffset) {
		for (int j = 0; j < bitmap.height; j++) {
			for (int i = 0; i < bitmap.width; i++) {
				game.data[(j + yOffset) * (GameComponent.MAGNIFIED) + (i + xOffset)] = bitmap.pixels[j * bitmap.width + i];
			}
		}
	}
}
